@@ -5,9 +5,10 @@ use File::Spec;
 use Path::Class;
 use Cwd;
 use Carp;
-use parent qw( Class::Accessor::Fast );
-
-__PACKAGE__->mk_accessors( qw( appname approot pmpath ) );
+use Class::Accessor::Lite (
+    new => 0,
+    rw => [qw( appname approot pmpath )],
+);
 
 sub new {
     my ( $class, %opts ) = @_;
@@ -17,7 +18,7 @@ sub new {
 
     $opts{pmpath} = file( File::Spec->catfile( $opts{approot}->stringify, 'lib', split(/::/, $opts{appname}. '.pm') ) );
 
-    return $class->SUPER::new( { %opts } );
+    return bless { %opts }, $class;
 }
 
 sub create {
@@ -77,6 +78,7 @@ sub app_class_file {
     my $body = $self->templates->{app_class_file};
     $body =~ s[\$approot][$approot]g;
     $body =~ s[\$appname][$appname]g;
+    $body =~ s[:::][=]g;
     $self->pmpath->dir->mkpath( 1, 0755 );
     $self->pmpath->spew( $body );
 }
@@ -142,14 +144,13 @@ psgi_file
 use strict;
 use warnings;
 use FindBin;
+use Config::Micro;
 use File::Spec;
-use File::Basename 'dirname';
 
 use lib ("$FindBin::Bin/lib", "$FindBin::Bin/extlib/lib/perl5");
 use $appname;
-my $basedir = dirname(__FILE__);
-my $config_name = $ENV{PLACK_ENV} || 'development';
-$appname->run( do(File::Spec->catfile($basedir, 'etc', 'conf', $config_name.'.pl')) );
+my $config = require( Config::Micro->file( dir => File::Spec->catdir('etc','conf') ) );
+$appname->run( $config );
 ===
 
 app_class_file
@@ -167,38 +168,48 @@ path '/' => sub {
         template => 'index.tx',
         title    => config->{appname},
         envname  => config->{envname},
+        apppath  => 'lib/' . __PACKAGE__ .'.pm',
+    };
+};
+
+path '/data' => sub {
+    my $req = shift;
+    return { # return JSON unless {template}
+        #template => 'index.tx',
+        title    => config->{appname},
+        envname  => config->{envname},
     };
 };
 
 1;
 __END__
 
-=head1 NAME
+:::head1 NAME
 
 $appname - Web Application
 
-=head1 SYNOPSIS
+:::head1 SYNOPSIS
 
   $ plackup
 
-=head1 DESCRIPTION
+:::head1 DESCRIPTION
 
 $appname is web application based Nephia.
 
-=head1 AUTHOR
+:::head1 AUTHOR
 
 clever guy
 
-=head1 SEE ALSO
+:::head1 SEE ALSO
 
 Nephia
 
-=head1 LICENSE
+:::head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
+:::cut
 
 ===
 
@@ -215,6 +226,36 @@ index_template_file
     <h1><: $title :></h1>
     <p><: $envname :></p>
   </div>
+
+  <div class="content">
+    <h2>Hello, Nephia world!</h2>
+    <p>Nephia is a mini web-application framework.</p>
+    <pre>
+    ### <: $apppath :>
+    use Nephia;
+
+    # <a href="/data">JSON responce sample</a>
+    path '/data' => sub {
+        my $req = shift;
+
+
+        return { # responce-value as JSON unless exists {template}
+            #template => 'index.tx',
+            title    => config->{appname},
+            envname  => config->{envname},
+        };  
+    };
+
+    </pre>
+  </div>
+
+  <div class="content">
+    And more...
+    <ul>
+      <li><a href="https://metacpan.org/module/Nephia">Read the documentation</a></li>
+    </ul>
+  </div>
+
   <address class="generated-by">Generated by Nephia</address>
 </body>
 </html>
@@ -254,6 +295,24 @@ div.title {
     text-shadow: 3px 3px 3px #000;
 }
 
+div.content {
+    background-color: #666;
+    width: 80%;
+    margin: 20px auto;
+    padding: 10px 30px;
+    border-radius: 20px;
+    box-shadow: 7px 10px 30px #000;
+}
+
+pre,ul {
+    line-height: 1.2em;
+    padding-top: 10px;
+    padding-bottom: 10px;
+    background-color: #ccc;
+    text-shadow:none;
+    color: #111;
+}
+
 address.generated-by {
     width: 80%;
     padding: 0px 30px;
@@ -308,9 +367,9 @@ done_testing;
 common_conf
 ---
 ### common config
-(
++{
     appname => '$appname',
-);
+};
 ===
 
 conf_file
@@ -321,7 +380,7 @@ use File::Basename 'dirname';
 my $basedir = File::Spec->rel2abs(
     File::Spec->catdir( dirname(__FILE__), '..', '..' )
 );
-(
-    ( do(File::Spec->catfile($basedir, 'etc', 'conf', 'common.pl')) ),
++{
+    %{ do(File::Spec->catfile($basedir, 'etc', 'conf', 'common.pl')) },
     envname => '$envname',
-);
+};
