@@ -5,7 +5,9 @@ use Nephia;
 use Mouse::Util::TypeConstraints;
 use utf8;
 
-our $VERSION = 0.01;
+our $VERSION = 0.06;
+
+nephia_plugins 'Bark';
 
 enum 'Sex' => qw( male female shemale );
 
@@ -91,6 +93,14 @@ post '/item/{newitem:.+}' => sub {
     };
 };
 
+path '/bark' => sub {
+    bark();
+};
+
+path '/barkbark' => sub {
+    barkbark(qw/foo bar/);
+};
+
 1;
 __END__
 
